@@ -1,22 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-#
-# Copyright (c) 2017-2022 Pytroll developers
-#
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
 """PySpectral configuration directory and file handling."""
 
 import logging
@@ -24,6 +5,7 @@ import os
 from collections.abc import Mapping
 from os.path import expanduser
 from pathlib import Path
+from typing import Any
 
 import yaml
 from platformdirs import AppDirs
@@ -56,14 +38,15 @@ def recursive_dict_update(d, u):
     return d
 
 
-def get_config(config_file: str | Path = None) -> dict:
+def get_config(config_file: str | Path | None = None) -> dict:
     """Get configuration options from YAML file."""
     if config_file is None:
         config_file = _get_env_or_builtin_config_path()
 
-    config = {}
+    config: dict[str, Any] = {}
     with open(config_file, 'r') as fp_:
-        config = recursive_dict_update(config, yaml.load(fp_, Loader=UnsafeLoader))
+        loaded_config_content = yaml.load(fp_, Loader=UnsafeLoader)
+    config = recursive_dict_update(config, loaded_config_content)
 
     app_dirs = AppDirs('pyspectral', 'pytroll')
     user_datadir = app_dirs.user_data_dir
