@@ -1,24 +1,4 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-#
-# Copyright (c) 2014-2022 Pytroll developers
-#
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-"""
-Converting between radiance and Tb.
+"""Converting between radiance and Tb.
 
 Conversion between radiances and brightness temperatures for the IR bands of
 various satellite sensors
@@ -170,7 +150,7 @@ class RadTbConverter(object):
         """Index the lut, numpy style."""
         return lut[block]
 
-    def tb2radiance(self, tb_, **kwargs):
+    def tb2radiance(self, tb_, lut=None, normalized=True):
         """Get the radiance from the brightness temperature (Tb) given the band name.
 
         Input:
@@ -184,9 +164,6 @@ class RadTbConverter(object):
             If False the radiance is the band integrated radiance. Default is True.
 
         """
-        lut = kwargs.get('lut', None)
-        normalized = kwargs.get('normalized', True)
-
         if self.wavespace == WAVE_NUMBER:
             if normalized:
                 unit = 'W/m^2 sr^-1 (m^-1)^-1'
