@@ -1,29 +1,9 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-#
-# Copyright (c) 2016-2019 Pytroll developers
-#
-# Author(s):
-#
-#   Adam.Dybbroe <a000680@c20671.ad.smhi.se>
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
 """Base class for reading raw instrument spectral responses."""
 
-import os
 import logging
+import os
+from pathlib import Path
+
 from pyspectral.config import get_config
 
 LOG = logging.getLogger(__name__)
@@ -48,14 +28,15 @@ class InstrumentRSR(object):
 
         self.output_dir = None
         self.path = None
+        self.filename = None
         self.options = {}
-        self.requested_band_filename = None
 
     def _get_options_from_config(self):
         """Get configuration settings from configuration file."""
         options = get_config()
         self.output_dir = options.get('rsr_dir', './')
-        self.path = options[self.platform_name + '-' + self.instrument]['path']
+        self.path = Path(options[self.platform_name + '-' + self.instrument]['path'])
+        self.filename = options[self.platform_name + '-' + self.instrument].get('filename')
         self.options = options
 
     def _get_bandfilenames(self):
