@@ -1,25 +1,4 @@
-#!/usr/bin/env python
-#
-# -*- coding: utf-8 -*-
-#
-# Copyright (c) 2013-2023 Pytroll developers
-#
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-"""
-Read solar irradiances and calculate solar flux.
+"""Read solar irradiances and calculate solar flux.
 
 Module to read solar irradiance spectra and calculate the solar flux over
 various instrument bands given their relative spectral response functions
@@ -165,10 +144,8 @@ class SolarIrradianceSpectrum(object):
         """
         from scipy.interpolate import InterpolatedUnivariateSpline
 
-        if 'detector' in options:
-            detector = options['detector']
-        else:
-            detector = 1
+        detector = options.get("detector", 1)
+        detector_name = f"det-{detector}"
 
         # Resample/Interpolate the response curve:
         if self.wavespace == 'wavelength':
@@ -176,15 +153,15 @@ class SolarIrradianceSpectrum(object):
                 wvl = rsr['wavelength'] * scale
                 resp = rsr['response']
             else:
-                wvl = rsr['det-{0:d}'.format(detector)]['wavelength'] * scale
-                resp = rsr['det-{0:d}'.format(detector)]['response']
+                wvl = rsr[detector_name]['wavelength'] * scale
+                resp = rsr[detector_name]['response']
         else:
             if 'response' in rsr:
                 wvl = rsr['wavenumber'] * scale
                 resp = rsr['response']
             else:
-                wvl = rsr['det-{0:d}'.format(detector)]['wavenumber'] * scale
-                resp = rsr['det-{0:d}'.format(detector)]['response']
+                wvl = rsr[detector_name]['wavenumber'] * scale
+                resp = rsr[detector_name]['response']
 
         start = wvl[0]
         end = wvl[-1]
