@@ -1,22 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-#
-# Copyright (c) 2014-2022 Pytroll developers
-#
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
 """Do the unit testing for the utils library."""
 import contextlib
 import logging
@@ -82,6 +63,10 @@ RESULT_RSR['20']['det-1']['response'] = np.array([
     0.0849, 0.05028, 0.03226, 0.01987, 0.0118, 0.01],
     dtype='float32')
 
+RESULT_BW_CALC = 6.73999984e-05
+RESULT_INTEG_ENER_ONEPERC = (2.61000005e-05, 0.00831819978)
+RESULT_INTEG_ENER_TENPERC = (0.000107899999, 0.00831819978)
+
 
 class _MockedRSR:
     def __init__(self, usedet=True):
@@ -222,6 +207,30 @@ class TestUtils(unittest.TestCase):
         np.testing.assert_allclose(wvl_range, expected_range)
 
 
+def test_get_fullwidth_halfmax():
+    """Test computation of the FWHM method of bandwidth calculation."""
+    rsr = RsrTestData()
+    res = utils.get_fullwidth_halfmax(rsr.rsr['ch3']['det-1']['wavelength'],
+                                      rsr.rsr['ch3']['det-1']['response'])
+    assert res == RESULT_BW_CALC
+
+
+@pytest.mark.parametrize(
+    ("ener_perc_lim", "exp_res"),
+    [
+        (1, RESULT_INTEG_ENER_ONEPERC),
+        (10, RESULT_INTEG_ENER_TENPERC),
+    ]
+)
+def test_get_bounds_integrated_energy(ener_perc_lim, exp_res):
+    """Get the inegrated energy method of bandwidth calculation."""
+    rsr = RsrTestData()
+    res1 = utils.get_bounds_integrated_energy(rsr.rsr['ch3']['det-1']['wavelength'],
+                                              rsr.rsr['ch3']['det-1']['response'],
+                                              ener_perc_lim=ener_perc_lim)
+    np.testing.assert_allclose(res1, exp_res)
+
+
 @pytest.mark.parametrize(
     ("input_value", "exp_except"),
     [
@@ -263,9 +272,11 @@ def test_download_rsr_dry_run():
     requests_mock.assert_not_called()
 
 
+@pytest.mark.allow_downloads(use=True)
 def test_download_rsr(tmp_path):
     """Test basic usage of the download_rsr function."""
-    tar_data = _create_fake_rsr_tarball_bytes()
+    version_data = "v1.2.3.4.5"
+    tar_data = _create_fake_rsr_tarball_bytes(version_data)
     with responses.RequestsMock() as rsps:
         rsps.add(
             "GET",
@@ -278,16 +289,19 @@ def test_download_rsr(tmp_path):
             },
         )
         utils.download_rsr(dest_dir=str(tmp_path))
-    assert os.path.isfile(tmp_path / "PYSPECTRAL_RSR_VERSION")
+    version_path = tmp_path / "PYSPECTRAL_RSR_VERSION"
+    assert version_path.is_file()
+    with version_path.open() as version_file:
+        assert version_file.read() == version_data
 
 
-def _create_fake_rsr_tarball_bytes():
+def _create_fake_rsr_tarball_bytes(version_data=utils.RSR_DATA_VERSION):
     file_obj = BytesIO()
 
     with tarfile.open(mode="w:gz", fileobj=file_obj) as rsr_tar:
         info = tarfile.TarInfo(utils.RSR_DATA_VERSION_FILENAME)
-        info.size = len(utils.RSR_DATA_VERSION)
-        rsr_tar.addfile(info, BytesIO(utils.RSR_DATA_VERSION.encode("ascii")))
+        info.size = len(version_data)
+        rsr_tar.addfile(info, BytesIO(version_data.encode("ascii")))
 
     file_obj.seek(0)
     return file_obj.read()
@@ -308,6 +322,7 @@ def test_download_luts_dry_run():
         (None, "desert_aerosol", True),
     ]
 )
+@pytest.mark.allow_downloads(use=True)
 def test_download_luts(tmp_path, aerosol_types, aerosol_type, exp_warning):
     """Test basic usage of the download_luts function."""
     atypes_to_create = _atypes_to_create(aerosol_types, aerosol_type)
